@@ -4,7 +4,7 @@ import shutil
 import requests
 from pathlib import Path
 
-from trace import MANAGE, REQUIREMENTS, WSGI, URLS, SETTINGS, VIEWS, MODELS, APP_URLS, ADMIN, README
+from .trace import MANAGE, REQUIREMENTS, WSGI, URLS, SETTINGS, VIEWS, MODELS, APP_URLS, ADMIN, README
 
 
 def generate(terminal_token, project_token, *args):
