@@ -9,11 +9,11 @@ def terminal():
         args = parser.parse_args()
 
         if args.action == 'generate':
-            from commands import generate
+            from .commands import generate
             return generate(args.terminal_token, args.project_token, args.dir)
 
         if args.action == 'sync':
-            from commands import sync
+            from .commands import sync
             return sync(args.terminal_token, args.project_token, args.dir)
         
         return False
